%Import all the spectra manually, (.txt-files)

f=PB_y(:,1);
n=length(PB_y);

%% Interpolating

PB_PB=interpol(PB_PB_import(:,2));
PB_DE=interpol(PB_DE_import(:,2));
PB_HPU=interpol(PB_HPU_import(:,2));

DE_PB=interpol(DE_PB_import(:,2));
DE_DE=interpol(DE_DE_import(:,2));
DE_HPU=interpol(DE_HPU_import(:,2));

HPU_PB=interpol(HPU_PB_import(:,2));
HPU_DE=interpol(HPU_DE_import(:,2));
HPU_HPU=interpol(HPU_HPU_import(:,2));

PB_SUP=interpol(PB_SUP_import(:,2));
DE_SUP=interpol(DE_SUP_import(:,2));
HPU_SUP=interpol(HPU_SUP_import(:,2));

%% Assembling
PB_PB_MAT=sparse(diag(PB_PB));
PB_DE_MAT=sparse(diag(PB_DE));
PB_HPU_MAT=sparse(diag(PB_HPU));

DE_PB_MAT=sparse(diag(DE_PB));
DE_DE_MAT=sparse(diag(DE_DE));
DE_HPU_MAT=sparse(diag(DE_HPU));

HPU_PB_MAT=sparse(diag(HPU_PB));
HPU_DE_MAT=sparse(diag(HPU_DE));
HPU_HPU_MAT=sparse(diag(HPU_HPU));

GIANT=[ PB_PB_MAT,  DE_PB_MAT,  HPU_PB_MAT;
        PB_DE_MAT,  DE_DE_MAT,  DE_HPU_MAT;
        PB_HPU_MAT, DE_HPU_MAT, HPU_HPU_MAT];

RESPONSE=[PB_y(:,2);DE_y(:,2);HPU_y(:,2)];

%% Solving

LOADS=GIANT\RESPONSE;

PB_load=LOADS(1:n);
DE_load=LOADS(n+1:2*n);
HPU_load=LOADS(2*n+1:end);

SUP_resp=PB_load.*PB_SUP+DE_load.*DE_SUP+HPU_load.*HPU_SUP;

%% Post processing

%Figure 1: Model verification
figure(1)
area(f,SUP_y2(:,2)/sqrt(2))
hold on
plot(f,SUP_resp/sqrt(2),':r')
xlabel('Frequency [Hz]')
ylabel('RMS velocity [m/s]')
title('Model verification')
legend('Measured response','Estimated response')
axis([2 1000 0 .9e-3])

%Figure 2: Equipment contribution
RESP_PB=PB_load.*PB_SUP;
rms_PB=sqrt(sum(RESP_PB.*RESP_PB))*1000*sqrt(1/1.5)/sqrt(2);
RESP_DE=DE_load.*DE_SUP;
rms_DE=sqrt(sum(RESP_DE.*RESP_DE))*1000*sqrt(1/1.5)/sqrt(2);
RESP_HPU=HPU_load.*HPU_SUP;
rms_HPU=sqrt(sum(RESP_HPU.*RESP_HPU))*1000*sqrt(1/1.5)/sqrt(2);
Y=[RESP_PB,RESP_DE,RESP_HPU]/sqrt(2);



figure(2)
area(f,Y)
legend('PB','DE','HPU')
axis([2 1000 0 2e-4])
title('Equipment contribution to deck vibration')
xlabel('Frequency [Hz]')
ylabel('RMS velocity [m/s]')

%Figure 3: Loads and deck response
figure(3) 
subplot(3,3,1)
plot(f,PB_load)
xlabel('Frequency [Hz]')
ylabel('F_{PB} [kN]')
axis([2 1000 0 1])

subplot(3,3,2)
plot(f,DE_load)
xlabel('Frequency [Hz]')
ylabel('F_{DE} [kN]')
axis([2 1000 0 50])

subplot(3,3,3)
plot(f,HPU_load)
xlabel('Frequency [Hz]')
ylabel('F_{HPU} [kN]')
axis([2 1000 0 50])

subplot(3,3,4)
plot(f,PB_SUP)
xlabel('Frequency [Hz]')
ylabel('FRF_{PB} [m/(s kN)]')
axis([2 1000 0 1e-4])

subplot(3,3,5)
plot(f,DE_SUP)
xlabel('Frequency [Hz]')
ylabel('FRF_{DE} [m/(s kN)]')
axis([2 1000 0 1e-4])

subplot(3,3,6)
plot(f,HPU_SUP)
xlabel('Frequency [Hz]')
ylabel('FRF_{HPU} [m/(s kN)]')
axis([2 1000 0 1e-4])

subplot(3,3,7:9)
plot(f,SUP_resp/sqrt(2))
xlabel('Frequency [Hz]')
ylabel('RMS velocity [m/s]')
axis([2 1000 0 .5e-3])